@@ -1,24 +1,13 @@
 """This program is self-checking!"""
 
+
 def replace_globals(f, new_globals):
     import sys
 
     if sys.version_info.major == 2:
-        args = [
-            f.func_code,
-            new_globals,
-            f.func_name,
-            f.func_defaults,
-            f.func_closure,
-        ]
+        args = [f.func_code, new_globals, f.func_name, f.func_defaults, f.func_closure]
     else:
-        args = [
-            f.__code__,
-            new_globals,
-            f.__name__,
-            f.__defaults__,
-            f.__closure__,
-        ]
+        args = [f.__code__, new_globals, f.__name__, f.__defaults__, f.__closure__]
     if hasattr(f, "_vm"):
         name = args.remove(args[2])
         args.insert(0, name)
@@ -28,7 +17,7 @@ def replace_globals(f, new_globals):
 
 def f():
     assert g() == 2
-    assert a == 1
+    assert a == 1  # noqa -- a is in the builtins and set to 2
 
 
 def g():
