@@ -6,16 +6,17 @@
 z = None
 del z
 
-exec('z=1+1\n')
+exec("z=1+1\n")
 
 if z != 2:
     assert False, "exec 'z=1+1'\n"
 del z
 
-exec('z=1+1')
+exec("z=1+1")
 
 # Make sure we can exec bytes as well as strings.
 import sys
+
 if sys.version_info[:2] >= (2, 5):
     if sys.version_info[:2] >= (3, 0):
         exec(bytes('# coding: cp949\na = "\xaa\xa7"\n', encoding="cp949"))
@@ -25,4 +26,4 @@ if sys.version_info[:2] >= (2, 5):
 # And one eval test...
 if not ((3, 0) <= sys.version_info[:2] <= (3, 2)):
     code = u'u"\xc2\xa4"\n'
-    assert eval(code) == u'\xc2\xa4'
+    assert eval(code) == u"\xc2\xa4"
