@@ -21,23 +21,25 @@ class GeneratorContextManager(object):
                 value = type()
             try:
                 self.gen.throw(type, value, traceback)
-                raise RuntimeError(
-                    "generator didn't stop after throw()"
-                )
+                raise RuntimeError("generator didn't stop after throw()")
             except StopIteration as exc:
                 return exc is not value
             except:
                 if sys.exc_info()[1] is not value:
                     raise
 
+
 def contextmanager(func):
     def helper(*args, **kwds):
         return GeneratorContextManager(func(*args, **kwds))
+
     return helper
 
+
 @contextmanager
 def my_context_manager(val):
     yield val
 
+
 with my_context_manager(17) as x:
     assert x == 17
