@@ -1,22 +1,27 @@
 """Bytecode Interpreter operations for Python 2.7
 """
-from __future__ import print_function, division
-
 import inspect
 import types
-from xdis import PYTHON_VERSION
-from xpython.byteop.byteop24 import ByteOp24
+from xdis.version_info import PYTHON_VERSION_TRIPLE
+from xpython.byteop.byteop24 import ByteOp24, Version_info
 from xpython.byteop.byteop26 import ByteOp26
 
 # Gone since 2.6
 del ByteOp24.JUMP_IF_FALSE
 del ByteOp24.JUMP_IF_TRUE
 
+
 def fmt_set_add(vm, arg, repr=repr):
     return " set.add(%s, %s)" % (repr(vm.peek(arg)), repr(vm.top()))
 
+
 def fmt_map_add(vm, arg, repr=repr):
-    return " dict.setitem(%s, %s, %s)" % (repr(vm.peek(arg)), repr(vm.top()), repr(vm.peek(2)))
+    return " dict.setitem(%s, %s, %s)" % (
+        repr(vm.peek(arg)),
+        repr(vm.top()),
+        repr(vm.peek(2)),
+    )
+
 
 class ByteOp27(ByteOp26):
     def __init__(self, vm):
@@ -24,6 +29,11 @@ class ByteOp27(ByteOp26):
         self.stack_fmt["SET_ADD"] = fmt_set_add
         self.stack_fmt["MAP_ADD"] = fmt_map_add
 
+        # Fake up version information
+        self.hexversion = 0x20712F0
+        self.version = "2.7.18 (default, Oct 27 1955, 00:00:00)\n[x-python]"
+        self.version_info = Version_info(2, 7, 18, "final", 0)
+
     def convert_method_native_func(self, frame, method):
         """If a method's function is a native functions, converted it to the
         corresponding PyVM Method so that we can interpret it.
@@ -37,7 +47,9 @@ class ByteOp27(ByteOp26):
                     break
                 pass
             else:
-                raise self.vm.PyVMError("Can't find method function attribute; tried '__func__' and '_im_func'")
+                raise self.vm.PyVMError(
+                    "Can't find method function attribute; tried '__func__' and '_im_func'"
+                )
             pass
 
         try:
@@ -96,18 +108,24 @@ class ByteOp27(ByteOp26):
         # Make sure __enter__ and __exit__ functions in context_manager are
         # converted to our Function type so we can interpret them.
         # Note though that built-in functions can't be traced.
-        if self.version == PYTHON_VERSION and not inspect.isbuiltin(context_manager.__exit__):
+        if self.version[:2] == PYTHON_VERSION_TRIPLE[:2] and not inspect.isbuiltin(
+            context_manager.__exit__
+        ):
             try:
-                exit_method = self.convert_method_native_func(self.vm.frame, context_manager.__exit__)
+                exit_method = self.convert_method_native_func(
+                    self.vm.frame, context_manager.__exit__
+                )
             except:
                 exit_method = context_manager.__exit__
         else:
             exit_method = context_manager.__exit__
         self.vm.push(exit_method)
-        if self.version == PYTHON_VERSION and not inspect.isbuiltin(context_manager.__enter__):
+        if self.version_info[:2] == PYTHON_VERSION_TRIPLE[:2] and not inspect.isbuiltin(
+            context_manager.__enter__
+        ):
             self.convert_method_native_func(self.vm.frame, context_manager.__enter__)
         finally_block = context_manager.__enter__()
-        if self.version < 3.0:
+        if self.version_info[:2] < (3, 0):
             self.vm.push_block("with", delta)
         else:
             self.vm.push_block("finally", delta)
@@ -155,6 +173,3 @@ class ByteOp27(ByteOp26):
             self.vm.jump(target)
         else:
             self.vm.pop()
-
-    def JUMP_ABSOLUTE(self, target):
-        self.vm.jump(target)
