@@ -1,12 +1,10 @@
 # -*- coding: utf-8 -*-
 """Bytecode Interpreter operations for Python 3.4
 """
-from __future__ import print_function, division
-
 import inspect
 import types
 
-from xdis import PYTHON_VERSION, IS_PYPY
+from xdis.version_info import PYTHON_VERSION_TRIPLE, IS_PYPY
 from xpython.byteop.byteop24 import Version_info
 from xpython.byteop.byteop32 import ByteOp32
 from xpython.byteop.byteop33 import ByteOp33
@@ -48,7 +46,7 @@ class ByteOp34(ByteOp33):
 
     # Python 3.3 docs describe this but seem to follow pre-3.3
     # conventions (which go back to Python 2.x days).
-    def MAKE_FUNCTION(self, argc):
+    def MAKE_FUNCTION(self, argc: int):
         """
         Pushes a new function object on the stack. From bottom to top, the consumed stack must consist of:
 
@@ -106,7 +104,7 @@ class ByteOp34(ByteOp33):
 
         if (
             inspect.iscode(code)
-            and self.version == PYTHON_VERSION
+            and self.version[:2] == PYTHON_VERSION_TRIPLE[:2]
             and self.is_pypy == IS_PYPY
         ):
             # Python 3.4 __build_class__ is more strict about what can be a
