@@ -2,15 +2,18 @@ import itertools
 import os
 import sys
 
-AUTO_DEBUG = os.getenv('XPYTHON_DEBUG')
+AUTO_DEBUG = os.getenv("XPYTHON_DEBUG")
 RECORD_INTERPLEVEL_TRACEBACK = True
 
+
 def strerror(errno):
     """Translate an error code to a unicode message string."""
     from pypy.module._codecs.locale import str_decode_locale_surrogateescape
+
     utf8, lgt = str_decode_locale_surrogateescape(os.strerror(errno))
     return utf8, lgt
 
+
 class OperationError(Exception):
     """Interpreter-level exception that signals an exception that should be
     sent to the application level.
@@ -48,14 +51,15 @@ class OperationError(Exception):
 
     def _async(self, space):
         "Check if this is an exception that should better not be caught."
-        return (self.match(space, space.w_SystemExit) or
-                self.match(space, space.w_KeyboardInterrupt))
+        return self.match(space, space.w_SystemExit) or self.match(
+            space, space.w_KeyboardInterrupt
+        )
         # note: an extra case is added in OpErrFmtNoArgs
 
     def __str__(self):
         "Convenience for tracebacks."
         s = self._w_value
-        space = getattr(self.w_type, 'space', None)
+        space = getattr(self.w_type, "space", None)
         if space is not None:
             if self.__class__ is not OperationError and s is None:
                 s, lgt = self._compute_value(space)
@@ -63,15 +67,15 @@ class OperationError(Exception):
                 s = space.text_w(s)
             except Exception:
                 pass
-        return '[%s: %s]' % (self.w_type, s)
+        return "[%s: %s]" % (self.w_type, s)
 
     def __repr__(self):
         "NOT_RPYTHON"
-        return 'OperationError(%s)' % (self.w_type)
+        return "OperationError(%s)" % (self.w_type)
 
     def errorstr(self, space, use_repr=False):
         "The exception class and value, as a string."
-        if not use_repr:    # see write_unraisable()
+        if not use_repr:  # see write_unraisable()
             self.normalize_exception(space)
         w_value = self.get_w_value(space)
         if space is None:
@@ -80,7 +84,8 @@ class OperationError(Exception):
             exc_value = str(w_value)
         else:
             exc_typename = space.text_w(
-                space.getattr(self.w_type, space.newtext('__name__')))
+                space.getattr(self.w_type, space.newtext("__name__"))
+            )
             if space.is_w(w_value, space.w_None):
                 exc_value = ""
             else:
@@ -91,12 +96,13 @@ class OperationError(Exception):
                         exc_value = space.text_w(space.str(w_value))
                 except OperationError:
                     # oups, cannot __str__ the exception object
-                    exc_value = ("<exception %s() failed>" %
-                                 ("repr" if use_repr else "str"))
+                    exc_value = "<exception %s() failed>" % (
+                        "repr" if use_repr else "str"
+                    )
         if not exc_value:
             return exc_typename
         else:
-            return '%s: %s' % (exc_typename, exc_value)
+            return "%s: %s" % (exc_typename, exc_value)
 
     def record_interpreter_traceback(self):
         """Records the current traceback inside the interpreter.
@@ -152,22 +158,27 @@ class OperationError(Exception):
             if self._application_traceback:
                 from pypy.interpreter.pytraceback import PyTraceback
                 from pypy.module.exceptions.interp_exceptions import W_BaseException
+
                 tb = self._application_traceback
-                if (isinstance(w_value, W_BaseException) and
-                    isinstance(tb, PyTraceback)):
+                if isinstance(w_value, W_BaseException) and isinstance(tb, PyTraceback):
                     # traceback hasn't escaped yet
                     w_value.w_traceback = tb
                 else:
                     # traceback has escaped
-                    space.setattr(w_value, space.newtext("__traceback__"),
-                                  self.get_w_traceback(space))
+                    space.setattr(
+                        w_value,
+                        space.newtext("__traceback__"),
+                        self.get_w_traceback(space),
+                    )
         else:
             # the only case left here is (inst, None), from a 'raise inst'.
             w_inst = w_type
             w_instclass = self._exception_getclass(space, w_inst)
             if not space.is_w(w_value, space.w_None):
-                raise oefmt(space.w_TypeError,
-                            "instance exception may not have a separate value")
+                raise oefmt(
+                    space.w_TypeError,
+                    "instance exception may not have a separate value",
+                )
             w_value = w_inst
             w_type = w_instclass
 
@@ -177,19 +188,23 @@ class OperationError(Exception):
     def _exception_getclass(self, space, w_inst, what="exceptions"):
         w_type = space.exception_getclass(w_inst)
         if not space.exception_is_valid_class_w(w_type):
-            raise oefmt(space.w_TypeError,
-                        "%s must derive from BaseException, not %N",
-                        what, w_type)
+            raise oefmt(
+                space.w_TypeError,
+                "%s must derive from BaseException, not %N",
+                what,
+                w_type,
+            )
         return w_type
 
-    def write_unraisable(self, space, where, w_object=None,
-                         with_traceback=False, extra_line=''):
+    def write_unraisable(
+        self, space, where, w_object=None, with_traceback=False, extra_line=""
+    ):
         # Note: since Python 3.5, unraisable exceptions are always
         # printed with a traceback.  Setting 'with_traceback=False'
         # only asks for a different format, starting with the message
         # "Exception Xxx ignored".
         if w_object is None:
-            objrepr = ''
+            objrepr = ""
         else:
             try:
                 objrepr = space.text_w(space.repr(w_object))
@@ -206,30 +221,29 @@ class OperationError(Exception):
             w_tb = self.get_w_traceback(space)
             if where or objrepr:
                 if with_traceback:
-                    first_line = 'From %s%s:\n' % (where, objrepr)
+                    first_line = "From %s%s:\n" % (where, objrepr)
                 else:
-                    first_line = 'Exception ignored in: %s%s\n' % (
-                        where, objrepr)
+                    first_line = "Exception ignored in: %s%s\n" % (where, objrepr)
             else:
                 # Note that like CPython, we don't normalize the
                 # exception here.  So from `'foo'.index('bar')` you get
                 # "Exception ValueError: 'substring not found' in x ignored"
                 # but from `raise ValueError('foo')` you get
                 # "Exception ValueError: ValueError('foo',) in x ignored"
-                first_line = ''
-            space.appexec([space.newtext(first_line),
-                           space.newtext(extra_line),
-                           w_t, w_v, w_tb],
-            """(first_line, extra_line, t, v, tb):
+                first_line = ""
+            space.appexec(
+                [space.newtext(first_line), space.newtext(extra_line), w_t, w_v, w_tb],
+                """(first_line, extra_line, t, v, tb):
                 import sys
                 sys.stderr.write(first_line)
                 if extra_line:
                     sys.stderr.write(extra_line)
                 import traceback
                 traceback.print_exception(t, v, tb)
-            """)
+            """,
+            )
         except OperationError:
-            pass   # ignored
+            pass  # ignored
 
     def get_w_value(self, space):
         w_value = self._w_value
@@ -250,6 +264,7 @@ class OperationError(Exception):
         got_exception=True.
         """
         from pypy.interpreter.pytraceback import PyTraceback
+
         tb = self._application_traceback
         if tb is not None and isinstance(tb, PyTraceback):
             tb.frame.mark_as_escaped()
@@ -270,7 +285,7 @@ class OperationError(Exception):
         space.setattr(w_value, space.newtext("__cause__"), w_cause)
 
     def get_w_traceback(self, space):
-        """Return a traceback or w_None. """
+        """Return a traceback or w_None."""
         tb = self.get_traceback()
         if tb is None:
             return space.w_None
@@ -285,6 +300,7 @@ class OperationError(Exception):
 
     def remove_traceback_module_frames(self, *module_names):
         from pypy.interpreter.pytraceback import PyTraceback
+
         tb = self._application_traceback
         while tb is not None and isinstance(tb, PyTraceback):
             if tb.frame.pycode.co_filename not in module_names:
@@ -293,8 +309,7 @@ class OperationError(Exception):
         self._application_traceback = tb
 
     def record_context(self, space, ec):
-        """Record a __context__ for this exception if one exists.
-        """
+        """Record a __context__ for this exception if one exists."""
         if self._context_recorded:
             return
         last = ec.sys_exc_info()
@@ -312,7 +327,7 @@ class OperationError(Exception):
         w_context = context.get_w_value(space)
         if not space.is_w(w_value, w_context):
             _break_context_cycle(space, w_value, w_context)
-            space.setattr(w_value, space.newtext('__context__'), w_context)
+            space.setattr(w_value, space.newtext("__context__"), w_context)
 
     def chain_exceptions_from_cause(self, space, exception):
         # XXX does this code really make sense?
@@ -327,6 +342,7 @@ class OperationError(Exception):
     # Otherwise the same OperationError is returned.
     def try_set_from_cause(self, space, message):
         from pypy.module.exceptions.interp_exceptions import W_BaseException
+
         self.normalize_exception(space)
         w_value = self.get_w_value(space)
         if not isinstance(w_value, W_BaseException):
@@ -345,8 +361,9 @@ class OperationError(Exception):
             return self
         # Try to create the new exception.
         try:
-            new_error = oefmt(space.type(w_value),
-                              "%s (%T: %S)", message, w_value, w_value)
+            new_error = oefmt(
+                space.type(w_value), "%s (%T: %S)", message, w_value, w_value
+            )
             new_error.normalize_exception(space)
             new_error.set_cause(space, w_value)
             # Copy the traceback, but it does not escape.
@@ -363,11 +380,11 @@ def _break_context_cycle(space, w_value, w_context):
     This is O(chain length) but context chains are usually very short
     """
     while True:
-        w_next = space.getattr(w_context, space.newtext('__context__'))
+        w_next = space.getattr(w_context, space.newtext("__context__"))
         if space.is_w(w_next, space.w_None):
             break
         if space.is_w(w_next, w_value):
-            space.setattr(w_context, space.newtext('__context__'), space.w_None)
+            space.setattr(w_context, space.newtext("__context__"), space.w_None)
             break
         w_context = w_next
 
@@ -376,9 +393,11 @@ class ClearedOpErr:
     def __init__(self, space):
         self.operr = OperationError(space.w_None, space.w_None)
 
+
 def get_cleared_operation_error(space):
     return space.fromcache(ClearedOpErr).operr
 
+
 # ____________________________________________________________
 # optimization only: avoid the slowest operation -- the string
 # formatting with '%' -- in the common case were we don't
@@ -386,29 +405,30 @@ def get_cleared_operation_error(space):
 
 _fmtcache = {}
 _fmtcache2 = {}
-_FMTS = tuple('8NRSTds')
+_FMTS = tuple("8NRSTds")
+
 
 def decompose_valuefmt(valuefmt):
     """Returns a tuple of string parts extracted from valuefmt,
     and a tuple of format characters."""
     formats = []
-    parts = valuefmt.split('%')
+    parts = valuefmt.split("%")
     i = 1
     while i < len(parts):
         if parts[i].startswith(_FMTS):
             formats.append(parts[i][0])
             parts[i] = parts[i][1:]
             i += 1
-        elif parts[i] == '':    # support for '%%'
-            parts[i-1] += '%' + parts[i+1]
-            del parts[i:i+2]
+        elif parts[i] == "":  # support for '%%'
+            parts[i - 1] += "%" + parts[i + 1]
+            del parts[i : i + 2]
         else:
-            fmts = '%%%s or %%%s' % (', %'.join(_FMTS[:-1]), _FMTS[-1])
-            raise ValueError("invalid format string (only %s supported)" %
-                             fmts)
+            fmts = "%%%s or %%%s" % (", %".join(_FMTS[:-1]), _FMTS[-1])
+            raise ValueError("invalid format string (only %s supported)" % fmts)
     assert len(formats) > 0, "unsupported: no % command found"
     return tuple(parts), tuple(formats)
 
+
 def get_operrcls2(valuefmt):
     strings, formats = decompose_valuefmt(valuefmt)
     assert len(strings) == len(formats) + 1
@@ -416,7 +436,8 @@ def get_operrcls2(valuefmt):
         OpErrFmt = _fmtcache2[formats]
     except KeyError:
         from rpython.rlib.unroll import unrolling_iterable
-        attrs = ['x%d' % i for i in range(len(formats))]
+
+        attrs = ["x%d" % i for i in range(len(formats))]
         entries = unrolling_iterable(zip(itertools.count(), formats, attrs))
 
         class OpErrFmt(OperationError):
@@ -434,14 +455,14 @@ def get_operrcls2(valuefmt):
                     lst[i + i] = self.xstrings[i]
                     lgt += len(self.xstrings[i])
                     value = getattr(self, attr)
-                    if fmt == 'd':
+                    if fmt == "d":
                         result = str(value)
                         lgt += len(result)
-                    elif fmt == 'R':
+                    elif fmt == "R":
                         s = space.repr(value)
                         result = space.utf8_w(s)
                         lgt += space.len_w(s)
-                    elif fmt == 'S':
+                    elif fmt == "S":
                         s = space.str(value)
                         result = space.utf8_w(s)
                         lgt += space.len_w(s)
@@ -449,19 +470,24 @@ def get_operrcls2(valuefmt):
                     # elif fmt == 'T':
                     #     result = space.type(value).name
                     #     lgt += rutf8.codepoints_in_utf8(result)
-                    elif fmt == 'N':
+                    elif fmt == "N":
                         result = value.getname(space)
                         lgt += len(result)
-                    elif fmt == '8':
+                    elif fmt == "8":
                         # u'str\uxxxx' -> 'str\xXX\xXX' -> u"'str\xXX\xXX'"
                         from pypy.interpreter import unicodehelper
-                        result, _lgt, pos  = unicodehelper.str_decode_utf8(
-                            value, 'replace', True,
-                            unicodehelper.decode_never_raise, True)
+
+                        result, _lgt, pos = unicodehelper.str_decode_utf8(
+                            value,
+                            "replace",
+                            True,
+                            unicodehelper.decode_never_raise,
+                            True,
+                        )
                         lgt += _lgt
                     elif isinstance(value, unicode):
                         # 's'
-                        result = str(value.encode('utf-8'))
+                        result = str(value.encode("utf-8"))
                         lgt += len(value)
                     # FIXME rocky: reinstate when needed
                     # else:
@@ -473,12 +499,13 @@ def get_operrcls2(valuefmt):
                     lst[i + i + 1] = result
                 lst[-1] = self.xstrings[-1]
                 lgt += len(self.xstrings[-1])
-                retval = ''.join(lst)
+                retval = "".join(lst)
                 return retval, lgt
 
         _fmtcache2[formats] = OpErrFmt
     return OpErrFmt, strings
 
+
 class OpErrFmtNoArgs(OperationError):
     def __init__(self, w_type, value):
         self._value = value
@@ -491,11 +518,14 @@ class OpErrFmtNoArgs(OperationError):
         # also matches a RuntimeError("maximum rec.") if the stack is
         # still almost full, because in this case it might be a better
         # idea to propagate the exception than eat it
-        if (self.w_type is space.w_RecursionError and
-            self._value == "maximum recursion depth exceeded"):
+        if (
+            self.w_type is space.w_RecursionError
+            and self._value == "maximum recursion depth exceeded"
+        ):
             return True
         return OperationError._async(self, space)
 
+
 def get_operr_class(valuefmt):
     try:
         result = _fmtcache[valuefmt]
@@ -503,6 +533,7 @@ def get_operr_class(valuefmt):
         result = _fmtcache[valuefmt] = get_operrcls2(valuefmt)
     return result
 
+
 def oefmt(w_type, valuefmt, *args):
     """Equivalent to OperationError(w_type, space.newtext(valuefmt % args)).
     More efficient in the (common) case where the value is not actually
@@ -523,17 +554,20 @@ def oefmt(w_type, valuefmt, *args):
     OpErrFmt, strings = get_operr_class(valuefmt)
     return OpErrFmt(w_type, strings, *args)
 
+
 def exception_from_errno(space, w_type, errno):
     msg, lgt = strerror(errno)
-    w_error = space.call_function(w_type, space.newint(errno),
-                                  space.newtext(msg, lgt))
+    w_error = space.call_function(w_type, space.newint(errno), space.newtext(msg, lgt))
     return OperationError(w_type, w_error)
 
+
 def exception_from_saved_errno(space, w_type):
     from rpython.rlib.rposix import get_saved_errno
+
     errno = get_saved_errno()
     return exception_from_errno(space, w_type, errno)
 
+
 def new_exception_class(space, name, w_bases=None, w_dict=None):
     """Create a new exception type.
     @param name: the name of the type.
@@ -541,8 +575,8 @@ def new_exception_class(space, name, w_bases=None, w_dict=None):
                     exception types.  default is space.w_Exception.
     @param w_dict: an optional dictionary to populate the class __dict__.
     """
-    if '.' in name:
-        module, name = name.rsplit('.', 1)
+    if "." in name:
+        module, name = name.rsplit(".", 1)
     else:
         module = None
     if w_bases is None:
@@ -551,20 +585,23 @@ def new_exception_class(space, name, w_bases=None, w_dict=None):
         w_bases = space.newtuple([w_bases])
     if w_dict is None:
         w_dict = space.newdict()
-    w_exc = space.call_function(
-        space.w_type, space.newtext(name), w_bases, w_dict)
+    w_exc = space.call_function(space.w_type, space.newtext(name), w_bases, w_dict)
     if module:
         space.setattr(w_exc, space.newtext("__module__"), space.newtext(module))
     return w_exc
 
+
 def new_import_error(space, w_msg, w_name, w_path):
     """Create a new instance of ImportError.
 
     The result corresponds to ImportError(msg, name=name, path=path)
     """
     return space.appexec(
-        [w_msg, w_name, w_path], """(msg, name, path):
-            return ImportError(msg, name=name, path=path)""")
+        [w_msg, w_name, w_path],
+        """(msg, name, path):
+            return ImportError(msg, name=name, path=path)""",
+    )
+
 
 def raise_import_error(space, w_msg, w_name, w_path):
     w_exc = new_import_error(space, w_msg, w_name, w_path)
