@@ -1,19 +1,21 @@
 """Implementations of Python fundamental objects for xpython."""
-from __future__ import print_function
-
 import collections
 import inspect
 import linecache
 import types
 from copy import copy
 from sys import stderr
-from xdis import CO_GENERATOR, CO_ITERABLE_COROUTINE, iscode, PYTHON3, PYTHON_VERSION
-if PYTHON_VERSION >= 3.4:
+from xdis import CO_GENERATOR, CO_ITERABLE_COROUTINE, iscode
+from xdis.version_info import PYTHON3, PYTHON_VERSION_TRIPLE
+
+if PYTHON_VERSION_TRIPLE >= (3, 4):
     from xpython.stdlib.types34 import _AsyncGeneratorWrapper
 else:
-    class _AsyncGeneratorWrapper():
+
+    class _AsyncGeneratorWrapper:
         pass
 
+
 import xpython.stdlib.inspect3 as inspect3
 import xpython.stdlib.inspect2 as inspect2
 
@@ -48,7 +50,7 @@ except:
 
 # Code with these names have an implicit .0 in them
 COMPREHENSION_FN_NAMES = frozenset(
-    ("<setcomp>", "<dictcomp>", "<listcomp>", "<genexpr>",)
+    ("<setcomp>", "<dictcomp>", "<listcomp>", "<genexpr>")
 )
 
 
@@ -144,19 +146,16 @@ class Function(object):
 
         self.func_globals = globs
         self.func_locals = vm.frame.f_locals
-        self.__dict__ = {
-            "version": vm.version,
-            "_vm": vm,
-        }
+        self.__dict__ = {"version": vm.version, "_vm": vm}
 
         self.__doc__ = (
             code.co_consts[0] if hasattr(code, "co_consts") and code.co_consts else None
         )
 
-        if vm.version >= 3.0:
+        if vm.version >= (3, 0):
             self.__annotations__ = annotations
             self.__kwdefaults__ = kwdefaults
-            if vm.version >= 3.4:
+            if vm.version >= (3, 4):
                 self.__qualname__ = qualname if qualname else self.__name__
             else:
                 assert qualname is None
@@ -190,9 +189,7 @@ class Function(object):
         # The intent in providing native functions is for use in type
         # testing, mostly. The functios should not be run, since that defeats our
         # ability to trace functions.
-        kw = {
-            "argdefs": self.func_defaults,
-        }
+        kw = {"argdefs": self.func_defaults}
         if closure:
             kw["closure"] = tuple(make_cell(0) for _ in closure)
 
@@ -224,8 +221,8 @@ class Function(object):
     def __get__(self, instance, owner):
         if instance is not None:
             return Method(instance, owner, self)
-        version = self.version if hasattr(self, "version") else PYTHON_VERSION
-        if version < 3.0:
+        version = self.version if hasattr(self, "version") else PYTHON_VERSION_TRIPLE
+        if version < (3, 0):
             return Method(None, owner, self)
         else:
             return self
@@ -238,7 +235,7 @@ class Function(object):
             # so just do the right thing.
             assert len(args) == 1 and not kwargs, "Surprising comprehension!"
             callargs = {".0": args[0]}
-        elif self._func and self.version == PYTHON_VERSION:
+        elif self._func and self.version[:2] == PYTHON_VERSION_TRIPLE[:2]:
             # Perhaps this branch can go and we just use the others.
             # It will require a *lot* more code from inspect.py to be added:
             # classes Signature, Parameter, etc.
@@ -249,12 +246,12 @@ class Function(object):
             # See 3.7.7. test_keywordonlyarg.py
 
             # To catch dynamic changes, we'll run a second check
-            if self.version >= 3.0:
+            if self.version >= (3, 0):
                 inspect3.getcallargs(self, *args, **kwargs)
             else:
                 inspect2.getcallargs(self, *args, **kwargs)
         else:
-            if self.version >= 3.0:
+            if self.version >= (3, 0):
                 callargs = inspect3.getcallargs(self, *args, **kwargs)
             else:
                 callargs = inspect2.getcallargs(self, *args, **kwargs)
@@ -263,7 +260,7 @@ class Function(object):
             self.func_code, callargs, self.func_globals, {}, self.__closure__
         )
         if self.__code__.co_flags & CO_GENERATOR:
-            qualname = self.__qualname__ if self._vm.version >= 3.4 else None
+            qualname = self.__qualname__ if self._vm.version >= (3, 4) else None
             gen = Generator(
                 g_frame=frame, name=self.__name__, qualname=qualname, vm=self._vm
             )
@@ -380,7 +377,13 @@ class Block(object):
 
 class Frame(object):
     def __init__(
-        self, f_code, f_globals, f_locals, f_back, version=PYTHON_VERSION, closure=None
+        self,
+        f_code,
+        f_globals,
+        f_locals,
+        f_back,
+        version=PYTHON_VERSION_TRIPLE,
+        closure=None,
     ):
         self.f_code = f_code
         self.f_globals = f_globals
@@ -477,11 +480,14 @@ class Frame(object):
 
         for byte_incr, line_incr in zip(byte_increments, line_increments):
             if isinstance(byte_incr, str):
-                return ord(byte_incr)
+                byte_incr = ord(byte_incr)
 
             byte_num += byte_incr
             if byte_num > self.f_lasti:
                 break
+            if isinstance(line_incr, str):
+                line_incr = ord(line_incr)
+
             line_num += line_incr
 
         return line_num
@@ -534,7 +540,7 @@ class Generator(object):
         self.gi_running = False
         self.gi_code = g_frame.f_code
         self.__name__ = g_frame.f_code.co_name
-        self.__qualname__ = qualname if g_frame.version >= 3.4 else None
+        self.__qualname__ = qualname if g_frame.version >= (3, 4) else None
 
     def __iter__(self):
         return self
@@ -559,11 +565,7 @@ class Generator(object):
 
 if __name__ == "__main__":
     frame = Frame(
-        traceback_from_frame.__code__,
-        globals(),
-        locals(),
-        None,
-        PYTHON_VERSION
+        traceback_from_frame.__code__, globals(), locals(), None, PYTHON_VERSION
     )
     print(frame)
 
